pub fn get_lang() -> Guard<Arc<LocaleState>>Expand description
Retrieves the current language state.
Returns a guard containing the Arc<LocaleState>. This is primarily used
internally by the lookup functions but is exposed for diagnostics.
pub fn get_lang() -> Guard<Arc<LocaleState>>Retrieves the current language state.
Returns a guard containing the Arc<LocaleState>. This is primarily used
internally by the lookup functions but is exposed for diagnostics.