pub fn lookup_dynamic<'a, B: BundleCollection + ?Sized, C: CacheStore + ?Sized>(
bundles: &'a B,
cache: &C,
key: &'a str,
args: &FluentArgs<'_>,
) -> Cow<'a, str>Expand description
Retrieves a localized message with arguments.
Even when arguments are provided, this function checks if the underlying message is actually static. If so, it ignores the arguments and returns the static string to preserve performance.
Arguments
bundles- The collection of Fluent bundles.cache- The static cache map.key- The message ID to look up.args- The arguments to interpolate into the message.