CacheStore

Trait CacheStore 

pub trait CacheStore: Sync + Send {
    // Required method
    fn get_entry(&self, lang: &str, key: &str) -> Option<CacheEntry>;
}
A store that maps (Locale, Key) to a CacheEntry.

This trait exists to abstract over the generated phf::Map and standard HashMaps used in testing.

Required Methods

fn get_entry(&self, lang: &str, key: &str) -> Option<CacheEntry>

Retrieves a cache entry for a specific language and message key.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl CacheStore for Map<&'static str, &'static Map<&'static str, CacheEntry>>

Source

fn get_entry(&self, lang: &str, key: &str) -> Option<CacheEntry>

Implementors